@@ -1,5 +1,5 @@
 from django.contrib import admin
-from django.urls import reverse
+from django.urls import reverse, NoReverseMatch
 from django.utils.html import format_html
 from django.utils.translation import ugettext_lazy as _
 
@@ -19,8 +19,11 @@ class AttachmentAdmin(admin.ModelAdmin):
     readonly_fields = ('_name',)
 
     def _name(self, obj):
-        url = reverse('staff-attachments', kwargs={'attachment_uid': obj.uid})
-        return format_html(f'<a href="{url}">{obj.name}</a>')
+        try:
+            url = reverse('staff-attachments', kwargs={'attachment_uid': obj.uid})
+            return format_html(f'<a href="{url}">{obj.name}</a>')
+        except NoReverseMatch:
+            return format_html(obj.name)
     _name.short_description = _('Имя')
     _name.admin_order_field = 'name'
 
